@@ -28,7 +28,6 @@
 #include <QVBoxLayout>
 #include <QGridLayout>
 
-#include <kiconloader.h>
 #include <klocalizedstring.h>
 
 #include "gui/guiprofile.h"
@@ -65,7 +64,7 @@ void DialogViewConfigurationItem::refreshItem()
 {
   setFlags((flags() | Qt::ItemIsDragEnabled) &  ~Qt::ItemIsDropEnabled);
   setText(_name);
-  setIcon(KIconLoader::global()->loadIcon( _iconName, KIconLoader::Small, IconSize(KIconLoader::Toolbar) ));
+  setIcon(QIcon::fromTheme(_iconName));
   setData(Qt::ToolTipRole, _id);  // a hack. I am giving up to do it right
   setData(Qt::DisplayRole, _name);
 }
@@ -147,7 +146,7 @@ DialogViewConfiguration::DialogViewConfiguration(QWidget *parent, ViewBase &view
    layout->addWidget(qlb);
    
    _glayout = new QGridLayout();
-   _glayout->setMargin(0);
+   _glayout->setContentsMargins(0, 0, 0, 0);
    layout->addLayout(_glayout);
 
    createPage();
